//--------------------------------------------------------------
// File     : main.c
// Datum    : 11.04.2014
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F4
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der LIN-Slave Library
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_lin_slave.h"
#include "stm32_ub_led.h"

int main(void)
{
  LIN_FRAME_t myFrame;
  LIN_ERR_t check;

  SystemInit(); // Quarz Einstellungen aktivieren

  // init der LEDs
  UB_Led_Init();

  // init der UART als LIN-Slave
  UB_LIN_Slave_Init();

  while(1)
  {
    // check ob ID per LIN empfangen
    check=UB_LIN_checkID(&myFrame);
    if(check==LIN_OK) {
      UB_Led_Toggle(LED_ORANGE);
      if(myFrame.frame_id==0x01) {
        //---------------------------------------
        // 2Bytes per LIN vom Master empfangen
        //---------------------------------------
        myFrame.data_len=2;
        check=UB_LIN_ReceiveData(&myFrame);
        if(check==LIN_OK) {
          // Daten pruefen
          if((myFrame.data[0]==0xA1) && (myFrame.data[1]==0xB2)) {
            UB_Led_Toggle(LED_GREEN);
          }
          else {
            UB_Led_Toggle(LED_RED);
          }
        }
      }
      else if(myFrame.frame_id==0x02) {
        //---------------------------------------
        // 1Byte per LIN zum Master senden
        //---------------------------------------
        myFrame.data_len=1;
        myFrame.data[0]=0xF9;
        check=UB_LIN_SendData(&myFrame);
        if(check==LIN_OK) UB_Led_Toggle(LED_BLUE);
      }
    }
  }
}

